@@ -1,6 +1,6 @@
 import random
 def randomInt_Float(fromInt,toInt):
-    randomnum = random.unifrom(fromInt,toInt)
+    randomnum = random.uniform(fromInt,toInt)
     return randomnum
 def randomInt_Integers(fromInt,toInt):
     randomnumber = random.randint(fromInt,toInt)
