@@ -27,3 +27,6 @@ def squareRoot_positiveNumber(number):
 def squareOfANumber(number):
     result = number * number
     return result
+def division(Divisor,Dividend):
+    result = 'the quotient is: %s'% (Dividend/Divisor)
+    return result
